=== modified file 'config.yaml'
--- config.yaml	2020-10-28 05:21:42 +0000
+++ config.yaml	2020-12-07 00:54:07 +0000
@@ -71,6 +71,12 @@
       effect running units, only newly added units.  An example would be
       '/dev/xvdb,/dev/xvdc' to specify two ephemeral disks for cache
       storage.
+  cache-memory-size:
+    default: 0
+    type: int
+    description: |
+      Configurable option (in MBytes) to tune/override memory used by
+      squid cache. If 0 or unset, then auto-calculate.
   cache-storage-size:
     default: 0
     type: int

=== modified file 'lib/ubuntu_repository_cache/squid.py'
--- lib/ubuntu_repository_cache/squid.py	2020-10-06 10:04:18 +0000
+++ lib/ubuntu_repository_cache/squid.py	2020-12-07 00:54:07 +0000
@@ -36,10 +36,7 @@
 
 
 def size_caches():
-    """Determine the sizes for in-memory/on-disk squid caches
-
-    This must be run at installation time.  Runtime tuning is unsupported.
-    """
+    """Determine the sizes for in-memory/on-disk squid caches"""
 
     avail_disk = 0
     for cache in unitdata.kv().get('squid-disk-caches'):
@@ -103,7 +100,6 @@
     host.service_pause(squid_service)
     stop()
 
-    size_caches()
     render_configs()
     init_caches()
 
@@ -165,6 +161,22 @@
     return cache_str
 
 
+def cache_mem():
+    """Generate 'cache_mem' lines for the squid configuration file.
+
+    Returns a string containing the cache_mem config
+    """
+    size_caches()
+
+    config = hookenv.config()
+    cache_mem = config.get('cache-memory-size', 0)
+    if not cache_mem:
+        cache_mem = unitdata.kv().get('squid-cache-mem')
+
+    cache_str = 'cache_mem {} MB'.format(str(cache_mem))
+    return cache_str
+
+
 @util.run_as_user('root')
 def render_configs():
     '''Render the configuration templates for all required services'''
@@ -172,8 +184,8 @@
     LOG('Rendering squid configuration templates')
     config = hookenv.config()
     context = {}
-    context['Cache_Config'] = cache_dirs()
-    context['Cache_Mem'] = unitdata.kv().get('squid-cache-mem')
+    context['Cache_Storage_Config'] = cache_dirs()
+    context['Cache_Memory_Config'] = cache_mem()
     context['Cache_Peers'] = peer_config()
     context['Cache_Hostname'] = hookenv.unit_private_ip()
     if config['squid_snmp']:

=== modified file 'lib/ubuntu_repository_cache/tests/test_squid.py'
--- lib/ubuntu_repository_cache/tests/test_squid.py	2020-08-11 04:12:28 +0000
+++ lib/ubuntu_repository_cache/tests/test_squid.py	2020-12-07 00:54:07 +0000
@@ -38,3 +38,18 @@
         }
         result = squid.cache_dirs()
         self.assertEqual(result, 'cache_dir aufs /srv 1000 16 256\n')
+
+    def test_squid_cache_mem(self):
+        self.mock_config.return_value = {
+            'squid-disk-caches': [['/srv', 2000]],
+            'cache-memory-size': 0,
+        }
+        result = squid.cache_mem()
+        self.assertEqual(result, 'cache_mem 2479 MB')
+
+        self.mock_config.return_value = {
+            'squid-disk-caches': [['/srv', 2000]],
+            'cache-memory-size': 1000,
+        }
+        result = squid.cache_mem()
+        self.assertEqual(result, 'cache_mem 1000 MB')

=== modified file 'templates/squid-deb-proxy/squid-deb-proxy.conf'
--- templates/squid-deb-proxy/squid-deb-proxy.conf	2020-04-14 12:55:36 +0000
+++ templates/squid-deb-proxy/squid-deb-proxy.conf	2020-12-07 00:54:07 +0000
@@ -39,7 +39,7 @@
 maximum_object_size 512 MB
 
 # cache directory
-{{ Cache_Config }}
+{{ Cache_Storage_Config }}
 
 # Cache swap more aggressive to avoid having the cache size going above the cache_dir size parameter
 cache_swap_low 80
@@ -51,7 +51,7 @@
 #access_log daemon:/var/log/squid-deb-proxy/access.log
 
 # tweaks to speed things up
-cache_mem {{ Cache_Mem }} MB
+{{ Cache_Memory_Config }}
 maximum_object_size_in_memory 30 MB
 
 collapsed_forwarding on

